package io.github.thehrz.proxyServerHelper;

import com.google.inject.Inject
import com.moandjiezana.toml.Toml
import com.velocitypowered.api.event.Subscribe
import com.velocitypowered.api.event.proxy.ProxyInitializeEvent
import com.velocitypowered.api.plugin.annotation.DataDirectory
import com.velocitypowered.api.proxy.ProxyServer
import io.github.thehrz.proxyServerHelper.listeners.PlayerDisconnectListener
import io.github.thehrz.proxyServerHelper.listeners.ServerPostConnectListener
import net.kyori.adventure.text.minimessage.MiniMessage
import org.slf4j.Logger
import java.nio.file.Files
import java.nio.file.Path

class ProxyServerHelper @Inject constructor(
    val server: ProxyServer,
    val logger: Logger,
    @DataDirectory private val dataDirectory: Path
) {
    lateinit var config: Toml
        private set
    val miniMessage = MiniMessage.miniMessage()

    companion object {
        lateinit var instance: ProxyServerHelper
    }

    private fun initConfig() {
        if (Files.notExists(dataDirectory)) {
            Files.createDirectory(dataDirectory)
        }
        val config = dataDirectory.resolve("config.toml")
        if (Files.notExists(config)) {
            javaClass.classLoader.getResourceAsStream("config.toml").use { stream ->
                stream?.let { Files.copy(it, config) }
            }
        }
        instance = this
        this.config = Toml().read(config.toFile())
    }

    @Subscribe
    fun onProxyInitialization(event: ProxyInitializeEvent) {
        initConfig()
        server.eventManager.register(this, ServerPostConnectListener())
        server.eventManager.register(this, PlayerDisconnectListener())
    }
}
